==> kipi-plugins-trinity-3.5.13.2.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/picasawebexport/plugin_picasawebexport.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2007-17-07
 * Description : a kipi plugin to export images to Picasa web service
 *
 * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef PLUGIN_PICASAWEBEXPORT_H
#define PLUGIN_PICASAWEBEXPORT_H

// Libkipi includes.

#include <libkipi/plugin.h>

// Local includes.

#include "picasawebwindow.h"

class KAction;

using namespace KIPIPicasawebExportPlugin;

class Plugin_PicasawebExport : public KIPI::Plugin
{
    Q_OBJECT
  TQ_OBJECT

public:

    Plugin_PicasawebExport(TQObject *parent, const char* name, const TQStringList &args);
    ~Plugin_PicasawebExport();

    virtual KIPI::Category category(KAction* action) const;
    virtual void setup(TQWidget*);

public slots:

    void slotActivate();

private:

    PicasawebWindow *m_dlg;
    KAction         *m_action;
};

#endif // PLUGIN_PICASAWEBEXPORT_H

==> kipi-plugins-trinity-14.0.13.tar.xz: kipi-plugins-trinity-14.0.13/kipi-plugins/picasawebexport/plugin_picasawebexport.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2007-17-07
 * Description : a kipi plugin to export images to Picasa web service
 *
 * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef PLUGIN_PICASAWEBEXPORT_H
#define PLUGIN_PICASAWEBEXPORT_H

// Libkipi includes.

#include <libkipi/plugin.h>

// Local includes.

#include "picasawebwindow.h"

class TDEAction;

using namespace KIPIPicasawebExportPlugin;

class Plugin_PicasawebExport : public KIPI::Plugin
{
    Q_OBJECT
  

public:

    Plugin_PicasawebExport(TQObject *parent, const char* name, const TQStringList &args);
    ~Plugin_PicasawebExport();

    virtual KIPI::Category category(TDEAction* action) const;
    virtual void setup(TQWidget*);

public slots:

    void slotActivate();

private:

    PicasawebWindow *m_dlg;
    TDEAction         *m_action;
};

#endif // PLUGIN_PICASAWEBEXPORT_H
